﻿namespace FlatData.SampleApp.Data
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel.DataAnnotations;

    using FizzWare.NBuilder;
    using System.Collections.ObjectModel;
    using System.Collections;

    public class ProductData
    {
        [DisplayAttribute(Name = "Sales Region (Attribute)")]
        public string Region
        {
            get;
            set;
        }

        // [DisplayAttribute(AutoGenerateField = false)]
        [DisplayFormat(DataFormatString = "Alabala")]
        public string City
        {
            get;
            set;
        }

        [Display(Name = "Sales Person (Attribute)", Description = "The names of the sales person.")]
        public string Seller
        {
            get;
            set;
        }

        public string Product
        {
            get;
            set;
        }

        // [DisplayFormat(DataFormatString = "{0:####} pcs.")]
        public int? Units
        {
            get;
            set;
        }

        [DisplayFormat(DataFormatString = "{0:C2}")]
        [DisplayAttribute(Name = "Cost")]
        public double Cost
        {
            get;
            set;
        }

        //[DisplayFormat(DataFormatString = "ddd dd MM yyyy")]
        public Nullable<DateTime> Date
        {
            get; set;
        }

        [Display(Name = "Vehicle Model (Attribute)")]
        public Car Vehicle
        {
            get;
            set;
        }

        public double? Profit
        {
            get { return 1; }
        }

        public static IEnumerable<ProductData> GenerateDataV2()
        {
            ObservableCollection<ProductData> data = new ObservableCollection<ProductData>();

            data.Add(new ProductData { Seller = "Mike", Product = "Product1", Cost = 10.00f, Region = "US" });
            data.Add(new ProductData { Seller = "Mike", Product = "Product2", Cost = 4.00f, Region = "Canada" });
            data.Add(new ProductData { Seller = "John", Product = "Product2", Cost = 4.00f, Region = "US" });
            data.Add(new ProductData { Seller = "John", Product = "Product3", Cost = 7.00f, Region = "US" });
            data.Add(new ProductData { Seller = "Joe", Product = "Product1", Cost = 10.00f, Region = "US" });
            data.Add(new ProductData { Seller = "Joe", Product = "Product3", Cost = 7.00f, Region = "Canada" });
            data.Add(new ProductData { Seller = "David", Product = "Product2", Cost = 4.00f, Region = "Canada" });
            data.Add(new ProductData { Seller = "David", Product = "Product3", Cost = 7.00f, Region = "Canada" });

            return data;
        }

        public static IEnumerable<ProductData> GenerateData()
        {
            //ObservableCollection<ProductData> data = new ObservableCollection<ProductData>();

            //data.Add(new ProductData { Seller = "A Mike", Product = "Product1", Cost = 10.00, Region = "US", Units = 3 });
            //data.Add(new ProductData { Seller = "A Mike", Product = "Product2", Cost = 4.00, Region = "Canada", Units = 2 });
            //data.Add(new ProductData { Seller = "B John", Product = "Product2", Cost = 4.00, Region = "US", Units = 5 });
            //data.Add(new ProductData { Seller = "B John", Product = "Product3", Cost = 7.00, Region = "US", Units = 9 });
            //data.Add(new ProductData { Seller = "C Joe", Product = "Product1", Cost = 10.00, Region = "US", Units = 11 });
            //data.Add(new ProductData { Seller = "C Joe", Product = "Product3", Cost = 7.00, Region = "Canada", Units = 4 });
            //data.Add(new ProductData { Seller = "D David", Product = "Product2", Cost = 4.00, Region = "Canada", Units = 3 });
            //data.Add(new ProductData { Seller = "D David", Product = "Product3", Cost = 7.00, Region = "Canada", Units = 3 });

            //return data;

            return Builder<ProductData>.CreateListOfSize(15).
                WhereTheFirst(1).
                    Have(p => p.Seller = "Alex").And(p => p.Product = "Product3").And(p => p.Cost = 2125.22567f).And(p => p.Region = "US").And(p => p.City = "New York").And(p => p.Units = 2).And(p => p.Date = DateTime.Now).And(p => p.Vehicle = new Car { Brand = "Ford", Model = "Mustang" }).
               AndTheNext(1).
                    Have(p => p.Seller = "Mike").And(p => p.Product = "Product2").And(p => p.Cost = 1f).And(p => p.Region = "Canada").And(p => p.City = "Ottawa").And(p => p.Units = 3).And(p => p.Date = DateTime.Parse("2011-03-03")).And(p => p.Vehicle = new Car { Brand = "Ford", Model = "Ka" }).
                AndTheNext(1).
                    Have(p => p.Seller = "Bill").And(p => p.Product = "Product3").And(p => p.Cost = 4.345f).And(p => p.Region = "US").And(p => p.City = "Miami").And(p => p.Units = 35).And(p => p.Date = DateTime.Parse("2009-12-03")).And(p => p.Vehicle = new Car { Brand = "Ford", Model = "Mustang" }).
                AndTheNext(1).
                    Have(p => p.Seller = "John").And(p => p.Product = "Product4").And(p => p.Cost = 1f).And(p => p.Region = "US").And(p => p.City = "New York").And(p => p.Units = 6).And(p => p.Date = DateTime.Now).And(p => p.Vehicle = new Car { Brand = "Ford", Model = "Mustang" }).
                AndTheNext(1).
                    Have(p => p.Seller = "Joe").And(p => p.Product = "Product5").And(p => p.Cost = 4.567f).And(p => p.Region = "US").And(p => p.City = "Miami").And(p => p.Units = 6).And(p => p.Date = DateTime.Parse("2009-11-03")).And(p => p.Vehicle = new Car { Brand = "Ford2", Model = "Mustang" }).
                AndTheNext(1).
                    Have(p => p.Seller = "Diana").And(p => p.Product = "Product6").And(p => p.Cost = 4.9999f).And(p => p.Region = "Canada").And(p => p.City = "Ontario").And(p => p.Units = 9).And(p => p.Date = DateTime.Now).And(p => p.Vehicle = new Car { Brand = "Ford2", Model = "Mustang" }).
                AndTheNext(1).
                    Have(p => p.Seller = "Kate").And(p => p.Product = "Product7").And(p => p.Cost = 3.220f).And(p => p.Region = "Canada").And(p => p.City = "Ontario").And(p => p.Units = 33).And(p => p.Date = DateTime.Parse("2010-12-03")).And(p => p.Vehicle = new Car { Brand = "Ford2", Model = "Mustang" }).
                AndTheNext(1).
                    Have(p => p.Seller = "Jason").And(p => p.Product = "Product8").And(p => p.Cost = 3f).And(p => p.Region = "Canada").And(p => p.City = "Ontario").And(p => p.Units = 4).And(p => p.Date = DateTime.Now).And(p => p.Vehicle = new Car { Brand = "Chevrolet", Model = "Corvette" }).
                AndTheNext(1).
                    Have(p => p.Seller = "Tom").And(p => p.Product = "Product9").And(p => p.Cost = 1f).And(p => p.Region = "Canada").And(p => p.City = "Ontario").And(p => p.Units = 6).And(p => p.Date = DateTime.Parse("2010-07-03")).And(p => p.Vehicle = new Car { Brand = "Chevrolet", Model = "Corvette" }).
                AndTheNext(1).
                    Have(p => p.Seller = "John").And(p => p.Product = "Product3").And(p => p.Cost = 4.00f).And(p => p.Region = null).And(p => p.City = "Ottawa").And(p => p.Units = 4).And(p => p.Date = DateTime.Now).And(p => p.Vehicle = new Car { Brand = "Chevrolet", Model = "Camaro" }).
                AndTheNext(1).
                    Have(p => p.Seller = "John").And(p => p.Product = "Product3").And(p => p.Cost = 1.321f).And(p => p.Region = null).And(p => p.City = "Ontario").And(p => p.Units = 9).And(p => p.Date = DateTime.Now).And(p => p.Vehicle = new Car { Brand = "Chevrolet", Model = "Corvette" }).
                AndTheNext(1).
                    Have(p => p.Seller = "Joe").And(p => p.Product = "Product1").And(p => p.Cost = 4.00f).And(p => p.Region = "Canada").And(p => p.City = "Ontario").And(p => p.Units = 5).And(p => p.Date = DateTime.Parse("2008-11-09")).And(p => p.Vehicle = new Car { Brand = "Chevrolet", Model = "Camaro" }).
                AndTheNext(1).
                    Have(p => p.Seller = "Joe").And(p => p.Product = "Product3").And(p => p.Cost = 4.00f).And(p => p.Region = "Canada").And(p => p.City = "Ontario").And(p => p.Units = 1).And(p => p.Date = DateTime.Parse("2010-08-03")).And(p => p.Vehicle = new Car { Brand = "Chevrolet", Model = "Camaro" }).
                AndTheNext(1).
                    Have(p => p.Seller = "Jæson").And(p => p.Product = "Product2").And(p => p.Cost = 3.5500f).And(p => p.Region = "Canada").And(p => p.City = "Ontario").And(p => p.Units = 3).And(p => p.Date = DateTime.Parse("2010-09-03")).And(p => p.Vehicle = new Car { Brand = "Chevrolet", Model = "Corvette" }).
                AndTheNext(1).
                    Have(p => p.Seller = "Jæson").And(p => p.Product = "Product3").And(p => p.Cost = 3.0f).And(p => p.Region = "Canada").And(p => p.City = "Ontario").And(p => p.Units = 2).And(p => p.Date = DateTime.Now).And(p => p.Vehicle = new Car { Brand = "Audi", Model = "A4" }).
                Build();

            //return Builder<ProductData>.CreateListOfSize(150000).
            //    WhereTheFirst(10000).
            //        Have(p => p.Seller = "Alex").And(p => p.Product = "Product1").And(p => p.Cost = 2125.22567).And(p => p.Region = "US").And(p => p.Units = 2).And(p => p.Date = DateTime.Now).And(p => p.Vehicle = new Car { Brand = "Ford", Model = "Mustang" }).
            //    AndTheNext(10000).
            //        Have(p => p.Seller = "Mike").And(p => p.Product = "Product2").And(p => p.Cost = 1).And(p => p.Region = "Canada").And(p => p.Units = 3).And(p => p.Date = DateTime.Parse("2009-12-03")).And(p => p.Vehicle = new Car { Brand = "Ford", Model = "Ka" }).
            //    AndTheNext(10000).
            //        Have(p => p.Seller = "Bill").And(p => p.Product = "Product3").And(p => p.Cost = 4.345).And(p => p.Region = "US").And(p => p.Units = 2).And(p => p.Date = DateTime.Parse("2009-12-03")).And(p => p.Vehicle = new Car { Brand = "Ford", Model = "Mustang" }).
            //    AndTheNext(10000).
            //        Have(p => p.Seller = "John").And(p => p.Product = "Product4").And(p => p.Cost = 1).And(p => p.Region = "US").And(p => p.Units = 6).And(p => p.Date = DateTime.Now).And(p => p.Vehicle = new Car { Brand = "Ford", Model = "Mustang" }).
            //    AndTheNext(10000).
            //        Have(p => p.Seller = "Joe").And(p => p.Product = "Product5").And(p => p.Cost = 4.567).And(p => p.Region = "US").And(p => p.Units = 3).And(p => p.Date = DateTime.Parse("2009-11-03")).And(p => p.Vehicle = new Car { Brand = "Ford", Model = "Mustang" }).
            //    AndTheNext(10000).
            //        Have(p => p.Seller = "Diana").And(p => p.Product = "Product6").And(p => p.Cost = 4.9999).And(p => p.Region = "Canada").And(p => p.Units = 9).And(p => p.Date = DateTime.Now).And(p => p.Vehicle = new Car { Brand = "Ford", Model = "Mustang" }).
            //    AndTheNext(10000).
            //        Have(p => p.Seller = "Kate").And(p => p.Product = "Product7").And(p => p.Cost = 3.220).And(p => p.Region = "Canada").And(p => p.Units = 33).And(p => p.Date = DateTime.Parse("2010-12-03")).And(p => p.Vehicle = new Car { Brand = "Ford", Model = "Mustang" }).
            //    AndTheNext(10000).
            //        Have(p => p.Seller = "Jason").And(p => p.Product = "Product8").And(p => p.Cost = 3).And(p => p.Region = "Canada").And(p => p.Units = 4).And(p => p.Date = DateTime.Now).And(p => p.Vehicle = new Car { Brand = "Chevrolet", Model = "Corvette" }).
            //    AndTheNext(10000).
            //        Have(p => p.Seller = "Tom").And(p => p.Product = "Product9").And(p => p.Cost = 1).And(p => p.Region = "Canada").And(p => p.Units = 6).And(p => p.Date = DateTime.Parse("2010-05-03")).And(p => p.Vehicle = new Car { Brand = "Chevrolet", Model = "Corvette" }).
            //    AndTheNext(10000).
            //        Have(p => p.Seller = "John").And(p => p.Product = "Product3").And(p => p.Cost = 4.00).And(p => p.Region = "Canada").And(p => p.Units = 4).And(p => p.Date = DateTime.Now).And(p => p.Vehicle = new Car { Brand = "Chevrolet", Model = "Camaro" }).
            //    AndTheNext(10000).
            //        Have(p => p.Seller = "John").And(p => p.Product = "Product3").And(p => p.Cost = 1.321).And(p => p.Region = "Canada").And(p => p.Units = 9).And(p => p.Date = DateTime.Now).And(p => p.Vehicle = new Car { Brand = "Chevrolet", Model = "Corvette" }).
            //    AndTheNext(10000).
            //        Have(p => p.Seller = "Joe").And(p => p.Product = "Product1").And(p => p.Cost = 4.00).And(p => p.Region = "Canada").And(p => p.Units = 5).And(p => p.Date = DateTime.Parse("2008-06-09")).And(p => p.Vehicle = new Car { Brand = "Chevrolet", Model = "Corvette" }).
            //    AndTheNext(10000).
            //        Have(p => p.Seller = "Joe").And(p => p.Product = "Product3").And(p => p.Cost = 4.00).And(p => p.Region = "Canada").And(p => p.Units = 1).And(p => p.Date = DateTime.Now).And(p => p.Vehicle = new Car { Brand = "Chevrolet", Model = "Corvette" }).
            //    AndTheNext(10000).
            //        Have(p => p.Seller = "Jason").And(p => p.Product = "Product2").And(p => p.Cost = 3.5500).And(p => p.Region = "Canada").And(p => p.Units = 3).And(p => p.Date = DateTime.Now).And(p => p.Vehicle = new Car { Brand = "Chevrolet", Model = "Corvette" }).
            //    AndTheNext(10000).
            //        Have(p => p.Seller = "Jason").And(p => p.Product = "Product3").And(p => p.Cost = 3.0).And(p => p.Region = "Canada").And(p => p.Units = 6).And(p => p.Date = DateTime.Now).And(p => p.Vehicle = new Car { Brand = "Chevrolet", Model = "Corvette" }).
            //    Build();
        }

        public static IList GenerateLiveUpdateData()
        {
            IList<ProductData> dataList = Builder<ProductData>.CreateListOfSize(500).Build();
            return new ObservableCollection<ProductData>(dataList);
        }
    }

    public class SampleData
    {
        public string Name { get; set; }
        public int Age { get; set; }
    }
}
